@@ -1,17 +1,15 @@
 import git
-import os
 import click
-from github import Github
-from github import GithubException
 from git import GitCommandError
 
 @click.command()
 @click.pass_context
-@click.option('-m', '--message', 'message')
-@click.option('-p', '--push', is_flag=True)
+@click.option('-m', '--message', 'message', help='Commit message')
+@click.option('-p', '--push', is_flag=True, help='Push to remote repository')
 def save(ctx, message, push):
-    "Git add ., git commit -m, git pull, git push if possible"
-
+    '''
+    Git add ., git commit -m, git pull, git push if possible
+    '''
     # Recover repo from context
     repo = ctx.obj['REPO']
     conflicted_files = get_conflict_files(repo)
